summaryrefslogtreecommitdiffstats
path: root/kviewshell/plugins/djvu
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-07-09 02:23:29 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-07-09 02:23:29 +0000
commitbce8199ddac4feecdee9c094fb8f75863cfa9652 (patch)
treeb0521e39686b4b24960a9d83e72a9c09937a810c /kviewshell/plugins/djvu
parent03d51915bf86a00c5953817c89976b62785bb5a1 (diff)
downloadtdegraphics-bce8199ddac4feecdee9c094fb8f75863cfa9652.tar.gz
tdegraphics-bce8199ddac4feecdee9c094fb8f75863cfa9652.zip
Remove the tq in front of these incorrectly TQt4-converted methods/data members:
tqrepaint[...] tqinvalidate[...] tqparent[...] tqmask[...] tqlayout[...] tqalignment[...] git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdegraphics@1240522 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kviewshell/plugins/djvu')
-rw-r--r--kviewshell/plugins/djvu/djvumultipage.cpp12
-rw-r--r--kviewshell/plugins/djvu/djvumultipage.h2
-rw-r--r--kviewshell/plugins/djvu/djvurenderer.cpp8
-rw-r--r--kviewshell/plugins/djvu/kprintDialogPage_DJVUconversionoptions_basewidget.ui2
-rw-r--r--kviewshell/plugins/djvu/libdjvu/DjVuDocEditor.cpp72
-rw-r--r--kviewshell/plugins/djvu/libdjvu/DjVuDocEditor.h2
-rw-r--r--kviewshell/plugins/djvu/libdjvu/DjVuDocument.cpp2
-rw-r--r--kviewshell/plugins/djvu/libdjvu/DjVuImage.cpp6
-rw-r--r--kviewshell/plugins/djvu/libdjvu/DjVuImage.h2
-rw-r--r--kviewshell/plugins/djvu/libdjvu/GIFFManager.cpp30
-rw-r--r--kviewshell/plugins/djvu/libdjvu/GIFFManager.h6
-rw-r--r--kviewshell/plugins/djvu/libdjvu/GThreads.cpp2
-rw-r--r--kviewshell/plugins/djvu/libdjvu/IW44EncodeCodec.cpp10
-rw-r--r--kviewshell/plugins/djvu/libdjvu/IW44Image.h6
-rw-r--r--kviewshell/plugins/djvu/libdjvu/JB2EncodeCodec.cpp2
-rw-r--r--kviewshell/plugins/djvu/pageRangeWidget_base.ui2
16 files changed, 83 insertions, 83 deletions
diff --git a/kviewshell/plugins/djvu/djvumultipage.cpp b/kviewshell/plugins/djvu/djvumultipage.cpp
index dbe68aaa..90ec1969 100644
--- a/kviewshell/plugins/djvu/djvumultipage.cpp
+++ b/kviewshell/plugins/djvu/djvumultipage.cpp
@@ -47,9 +47,9 @@ typedef KParts::GenericFactory<DjVuMultiPage> DjVuMultiPageFactory;
K_EXPORT_COMPONENT_FACTORY(djvuviewpart, DjVuMultiPageFactory)
-DjVuMultiPage::DjVuMultiPage(TQWidget *tqparentWidget, const char *widgetName, TQObject *tqparent,
+DjVuMultiPage::DjVuMultiPage(TQWidget *parentWidget, const char *widgetName, TQObject *tqparent,
const char *name, const TQStringList&)
- : KMultiPage(tqparentWidget, widgetName, tqparent, name), djvuRenderer(tqparentWidget)
+ : KMultiPage(parentWidget, widgetName, tqparent, name), djvuRenderer(parentWidget)
{
/* This is kparts wizardry that cannot be understood by man. Simply
change the names to match your implementation. */
@@ -162,7 +162,7 @@ void DjVuMultiPage::slotDeletePages()
if (numberOfPages() == 0)
return;
- KDialogBase dialog( tqparentWdg, "urldialog", true, i18n("Delete Pages"), KDialogBase::Ok|KDialogBase::Cancel, KDialogBase::Ok, true );
+ KDialogBase dialog( parentWdg, "urldialog", true, i18n("Delete Pages"), KDialogBase::Ok|KDialogBase::Cancel, KDialogBase::Ok, true );
PageRangeWidget range( 1, numberOfPages(), currentPageNumber(), &dialog, "range widget" );
TQToolTip::add( &range, i18n( "Select the pages you wish to delete." ) );
dialog.setButtonOK(i18n("Delete Pages"));
@@ -220,7 +220,7 @@ void DjVuMultiPage::print()
printer->addDialogPage( conversionOptions );
// initialize the printer using the print dialog
- if ( printer->setup(tqparentWdg, i18n("Print %1").tqarg(m_file.section('/', -1))) ) {
+ if ( printer->setup(parentWdg, i18n("Print %1").tqarg(m_file.section('/', -1))) ) {
// Now do the printing.
TQValueList<int> pageList = printer->pageList();
if (pageList.isEmpty())
@@ -334,7 +334,7 @@ void DjVuMultiPage::slotSave()
fileName = fileName+ending;
if (TQFile(fileName).exists()) {
- int r = KMessageBox::warningContinueCancel(tqparentWdg, i18n("The file %1\nalready exists. Do you want to overwrite it?").tqarg(fileName),
+ int r = KMessageBox::warningContinueCancel(parentWdg, i18n("The file %1\nalready exists. Do you want to overwrite it?").tqarg(fileName),
i18n("Overwrite File"), i18n("Overwrite"));
if (r == KMessageBox::Cancel)
return;
@@ -344,7 +344,7 @@ void DjVuMultiPage::slotSave()
/*
if (!djvuRenderer.save(fileName) == false)
- KMessageBox::error( tqparentWdg,
+ KMessageBox::error( parentWdg,
i18n("<qt><strong>File error.</strong> Unable to write to the specified file '%1'. The document is <strong>not</strong> saved.</qt>").tqarg(fileName),
i18n("File Error"));
*/
diff --git a/kviewshell/plugins/djvu/djvumultipage.h b/kviewshell/plugins/djvu/djvumultipage.h
index 83e94e40..eaad8a53 100644
--- a/kviewshell/plugins/djvu/djvumultipage.h
+++ b/kviewshell/plugins/djvu/djvumultipage.h
@@ -96,7 +96,7 @@ public:
kmultipage. Please have a look at the constructor's source code to
see how to adjust this for your implementation.
*/
- DjVuMultiPage(TQWidget *tqparentWidget, const char *widgetName, TQObject *tqparent,
+ DjVuMultiPage(TQWidget *parentWidget, const char *widgetName, TQObject *tqparent,
const char *name, const TQStringList& args = TQStringList());
/** Destructor
diff --git a/kviewshell/plugins/djvu/djvurenderer.cpp b/kviewshell/plugins/djvu/djvurenderer.cpp
index e1cbd044..8084e327 100644
--- a/kviewshell/plugins/djvu/djvurenderer.cpp
+++ b/kviewshell/plugins/djvu/djvurenderer.cpp
@@ -270,7 +270,7 @@ bool DjVuRenderer::setFile(const TQString &fname, const KURL &)
TQFileInfo fi(fname);
TQString filename = fi.absFilePath();
if (!fi.exists() || fi.isDir()) {
- KMessageBox::error( tqparentWidget,
+ KMessageBox::error( parentWidget,
i18n("<qt><strong>File error.</strong> The specified file '%1' does not exist.</qt>").tqarg(filename),
i18n("File Error"));
// the return value 'false' indicates that this operation was not successful.
@@ -292,7 +292,7 @@ bool DjVuRenderer::setFile(const TQString &fname, const KURL &)
// If the above assumption was false.
if (!document)
{
- KMessageBox::error( tqparentWidget,
+ KMessageBox::error( parentWidget,
i18n("<qt><strong>File error.</strong> The specified file '%1' could not be loaded.</qt>").tqarg(filename),
i18n("File Error"));
@@ -577,7 +577,7 @@ bool DjVuRenderer::convertToPSFile( DjVuToPS &converter, TQString filename, TQVa
TQMutexLocker locker( &mutex );
// Set up progress dialog
- KProgressDialog *pdialog = new KProgressDialog(tqparentWidget, "Printing-ProgressDialog", i18n("Printing..."), i18n("Preparing pages for printing..."), true);
+ KProgressDialog *pdialog = new KProgressDialog(parentWidget, "Printing-ProgressDialog", i18n("Printing..."), i18n("Preparing pages for printing..."), true);
pdialog->setButtonText(i18n("Abort"));
pdialog->showCancelButton(true);
pdialog->progressBar()->setTotalSteps(pageList.size());
@@ -634,7 +634,7 @@ void DjVuRenderer::deletePages(TQ_UINT16 from, TQ_UINT16 to)
KProgressDialog *pdialog = 0;
if (to-from > 9) {
- pdialog = new KProgressDialog(tqparentWidget, "Printing-ProgressDialog", i18n("Deleting pages..."), i18n("Please wait while pages are removed..."), true);
+ pdialog = new KProgressDialog(parentWidget, "Printing-ProgressDialog", i18n("Deleting pages..."), i18n("Please wait while pages are removed..."), true);
pdialog->showCancelButton(false);
pdialog->progressBar()->setTotalSteps(to-from+1);
pdialog->progressBar()->setFormat(TQString());
diff --git a/kviewshell/plugins/djvu/kprintDialogPage_DJVUconversionoptions_basewidget.ui b/kviewshell/plugins/djvu/kprintDialogPage_DJVUconversionoptions_basewidget.ui
index 416b7b36..bfaf546c 100644
--- a/kviewshell/plugins/djvu/kprintDialogPage_DJVUconversionoptions_basewidget.ui
+++ b/kviewshell/plugins/djvu/kprintDialogPage_DJVUconversionoptions_basewidget.ui
@@ -141,5 +141,5 @@
</spacer>
</grid>
</widget>
-<tqlayoutdefaults spacing="6" margin="0"/>
+<layoutdefaults spacing="6" margin="0"/>
</UI>
diff --git a/kviewshell/plugins/djvu/libdjvu/DjVuDocEditor.h b/kviewshell/plugins/djvu/libdjvu/DjVuDocEditor.h
index 96b18a06..7bf6124a 100644
--- a/kviewshell/plugins/djvu/libdjvu/DjVuDocEditor.h
+++ b/kviewshell/plugins/djvu/libdjvu/DjVuDocEditor.h
@@ -199,7 +199,7 @@ public:
an exception is thrown. */
GUTF8String page_to_id(int page_num) const;
- GUTF8String insert_file(const GURL &url, const GUTF8String &tqparent_id,
+ GUTF8String insert_file(const GURL &url, const GUTF8String &parent_id,
int chunk_num=1, DjVuPort *source=0);
/** Inserts the referenced file into this DjVu document.
diff --git a/kviewshell/plugins/djvu/libdjvu/DjVuDocument.cpp b/kviewshell/plugins/djvu/libdjvu/DjVuDocument.cpp
index 0ba922b3..ed998923 100644
--- a/kviewshell/plugins/djvu/libdjvu/DjVuDocument.cpp
+++ b/kviewshell/plugins/djvu/libdjvu/DjVuDocument.cpp
@@ -1328,7 +1328,7 @@ DjVuDocument::get_thumbnail(int page_num, bool dont_decode)
}
}
- // Aptqparently we're out of luck and need to decode the requested
+ // Apparently we're out of luck and need to decode the requested
// page (unless it's already done and if it's allowed) and render
// it into the thumbnail. If dont_decode is true, do not attempt
// to create this file (because this will result in a request for data)
diff --git a/kviewshell/plugins/djvu/libdjvu/DjVuImage.cpp b/kviewshell/plugins/djvu/libdjvu/DjVuImage.cpp
index acba10f2..e6e1c2ce 100644
--- a/kviewshell/plugins/djvu/libdjvu/DjVuImage.cpp
+++ b/kviewshell/plugins/djvu/libdjvu/DjVuImage.cpp
@@ -91,7 +91,7 @@ namespace DJVU {
//// DJVUIMAGE: CONSTRUCTION
DjVuImage::DjVuImage(void)
-: rotate_count(-1),retqlayout_sent(false)
+: rotate_count(-1),relayout_sent(false)
{
}
@@ -423,13 +423,13 @@ DjVuImage::get_long_description() const
void
DjVuImage::notify_chunk_done(const DjVuPort *, const GUTF8String & name)
{
- if (!retqlayout_sent &&
+ if (!relayout_sent &&
( !name.cmp("INFO", 4) ||
!name.cmp("PMxx", 2) ||
!name.cmp("BMxx", 2) ) )
{
DjVuPort::get_portcaster()->notify_retqlayout(this);
- retqlayout_sent=true;
+ relayout_sent=true;
}
else if (!name.cmp("Sxxx", 1) ||
!name.cmp("BGxx", 2) ||
diff --git a/kviewshell/plugins/djvu/libdjvu/DjVuImage.h b/kviewshell/plugins/djvu/libdjvu/DjVuImage.h
index 7f2e836a..30fc9898 100644
--- a/kviewshell/plugins/djvu/libdjvu/DjVuImage.h
+++ b/kviewshell/plugins/djvu/libdjvu/DjVuImage.h
@@ -414,7 +414,7 @@ public:
private:
GP<DjVuFile> file;
int rotate_count;
- bool retqlayout_sent;
+ bool relayout_sent;
// HELPERS
int stencil(GPixmap *pm, const GRect &rect, int subs, double gcorr) const;
diff --git a/kviewshell/plugins/djvu/libdjvu/GThreads.cpp b/kviewshell/plugins/djvu/libdjvu/GThreads.cpp
index 3b52faca..fa924324 100644
--- a/kviewshell/plugins/djvu/libdjvu/GThreads.cpp
+++ b/kviewshell/plugins/djvu/libdjvu/GThreads.cpp
@@ -1397,7 +1397,7 @@ cotask_select(int nfds,
}
// reschedule
cotask_yield();
- // call select to update tqmasks
+ // call select to update masks
if (tm)
{
tm->tv_sec = maxwait/1000;
diff --git a/kviewshell/plugins/djvu/libdjvu/IW44Image.h b/kviewshell/plugins/djvu/libdjvu/IW44Image.h
index 954eee56..0363a1fb 100644
--- a/kviewshell/plugins/djvu/libdjvu/IW44Image.h
+++ b/kviewshell/plugins/djvu/libdjvu/IW44Image.h
@@ -140,7 +140,7 @@
routine can use an optional bilevel image named the tqmask. Every non zero
pixel in the tqmask means the value of the corresponding pixel in the
background image is irrelevant. The wavelet decomposition code will
- replace these tqmasked pixels by a color value whose coding cost is minimal
+ replace these masked pixels by a color value whose coding cost is minimal
(see \URL{http://www.research.att.com/~leonb/DJVU/tqmask}).
{\bf ToDo} --- There are many improvements to be made. Besides better
@@ -278,12 +278,12 @@ public:
/** Initializes an IWBitmap with image #bm#. This constructor
performs the wavelet decomposition of image #bm# and records the
corresponding wavelet coefficient. Argument #tqmask# is an optional
- bilevel image specifying the tqmasked pixels (see \Ref{IW44Image.h}). */
+ bilevel image specifying the masked pixels (see \Ref{IW44Image.h}). */
static GP<IW44Image> create_encode(const GBitmap &bm, const GP<GBitmap> tqmask=0);
/** Initializes an IWPixmap with color image #bm#. This constructor
performs the wavelet decomposition of image #bm# and records the
corresponding wavelet coefficient. Argument #tqmask# is an optional
- bilevel image specifying the tqmasked pixels (see \Ref{IW44Image.h}).
+ bilevel image specifying the masked pixels (see \Ref{IW44Image.h}).
Argument #crcbmode# specifies how the chrominance information should be
encoded (see \Ref{CRCBMode}). */
static GP<IW44Image> create_encode(const GPixmap &bm, const GP<GBitmap> tqmask=0, CRCBMode crcbmode=CRCBnormal);
diff --git a/kviewshell/plugins/djvu/libdjvu/JB2EncodeCodec.cpp b/kviewshell/plugins/djvu/libdjvu/JB2EncodeCodec.cpp
index 57dd5200..3ff9d7df 100644
--- a/kviewshell/plugins/djvu/libdjvu/JB2EncodeCodec.cpp
+++ b/kviewshell/plugins/djvu/libdjvu/JB2EncodeCodec.cpp
@@ -467,7 +467,7 @@ JB2Dict::JB2Codec::Encode::code(const GP<JB2Image> &gjim)
// Avoid coding null tqshapes/blits
else if (jshp.bits)
{
- // Make sure all tqparents have been coded
+ // Make sure all parents have been coded
if (jshp.tqparent>=0 && tqshape2lib[jshp.tqparent]<0)
encode_libonly_tqshape(gjim, jshp.tqparent);
// Allocate library entry when needed
diff --git a/kviewshell/plugins/djvu/pageRangeWidget_base.ui b/kviewshell/plugins/djvu/pageRangeWidget_base.ui
index 90f85b5a..943f0201 100644
--- a/kviewshell/plugins/djvu/pageRangeWidget_base.ui
+++ b/kviewshell/plugins/djvu/pageRangeWidget_base.ui
@@ -65,7 +65,7 @@
</widget>
<customwidgets>
</customwidgets>
-<tqlayoutdefaults spacing="6" margin="11"/>
+<layoutdefaults spacing="6" margin="11"/>
<includehints>
<includehint>knuminput.h</includehint>
<includehint>knuminput.h</includehint>
diff --git a/kviewshell/plugins/djvu/libdjvu/DjVuDocEditor.cpp b/kviewshell/plugins/djvu/libdjvu/DjVuDocEditor.cpp
index fa6ad375..8bbc6db6 100644
--- a/kviewshell/plugins/djvu/libdjvu/DjVuDocEditor.cpp
+++ b/kviewshell/plugins/djvu/libdjvu/DjVuDocEditor.cpp
@@ -433,15 +433,15 @@ DjVuDocEditor::strip_incl_chunks(const GP<DataPool> & pool_in)
}
GUTF8String
-DjVuDocEditor::insert_file(const GURL &file_url, const GUTF8String &tqparent_id,
+DjVuDocEditor::insert_file(const GURL &file_url, const GUTF8String &parent_id,
int chunk_num, DjVuPort *source)
// Will open the 'file_name' and insert it into an existing DjVuFile
// with ID 'tqparent_id'. Will insert the INCL chunk at position chunk_num
// Will NOT process ANY files included into the file being inserted.
// Moreover it will strip out any INCL chunks in that file...
{
DEBUG_MSG("DjVuDocEditor::insert_file(): fname='" << file_url <<
- "', tqparent_id='" << tqparent_id << "'\n");
+ "', parent_id='" << parent_id << "'\n");
DEBUG_MAKE_INDENT(3);
const GP<DjVmDir> dir(get_djvm_dir());
@@ -469,16 +469,16 @@ DjVuDocEditor::insert_file(const GURL &file_url, const GUTF8String &tqparent_id,
file_pool=strip_incl_chunks(file_pool);
// Check if tqparent ID is valid
- GP<DjVmDir::File> tqparent_frec(dir->id_to_file(tqparent_id));
- if (!tqparent_frec)
- tqparent_frec=dir->name_to_file(tqparent_id);
- if (!tqparent_frec)
- tqparent_frec=dir->title_to_file(tqparent_id);
- if (!tqparent_frec)
- G_THROW( ERR_MSG("DjVuDocEditor.no_file") "\t" +tqparent_id);
- const GP<DjVuFile> tqparent_file(get_djvu_file(tqparent_id));
- if (!tqparent_file)
- G_THROW( ERR_MSG("DjVuDocEditor.create_fail") "\t"+tqparent_id);
+ GP<DjVmDir::File> parent_frec(dir->id_to_file(parent_id));
+ if (!parent_frec)
+ parent_frec=dir->name_to_file(parent_id);
+ if (!parent_frec)
+ parent_frec=dir->title_to_file(parent_id);
+ if (!parent_frec)
+ G_THROW( ERR_MSG("DjVuDocEditor.no_file") "\t" +parent_id);
+ const GP<DjVuFile> parent_file(get_djvu_file(parent_id));
+ if (!parent_file)
+ G_THROW( ERR_MSG("DjVuDocEditor.create_fail") "\t"+parent_id);
// Now obtain ID for the new file
const GUTF8String id(find_unique_id(file_url.fname()));
@@ -486,7 +486,7 @@ DjVuDocEditor::insert_file(const GURL &file_url, const GUTF8String &tqparent_id,
// Add it into the directory
const GP<DjVmDir::File> frec(
DjVmDir::File::create(id, id, id, DjVmDir::File::INCLUDE));
- int pos=dir->get_file_pos(tqparent_frec);
+ int pos=dir->get_file_pos(parent_frec);
if (pos>=0)
++pos;
dir->insert_file(frec, pos);
@@ -500,7 +500,7 @@ DjVuDocEditor::insert_file(const GURL &file_url, const GUTF8String &tqparent_id,
}
// And insert it into the tqparent DjVuFile
- tqparent_file->insert_file(id, chunk_num);
+ parent_file->insert_file(id, chunk_num);
return id;
}
@@ -930,7 +930,7 @@ DjVuDocEditor::generate_ref_map(const GP<DjVuFile> & file,
GMap<GUTF8String, void *> & ref_map,
GMap<GURL, void *> & visit_map)
// This private function is used to generate a list (implemented as map)
// of files referencing the given file. To get list of all tqparents
// for file with ID 'id' iterate map obtained as
// *((GMap<GUTF8String, void *> *) ref_map[id])
{
@@ -944,17 +944,17 @@ DjVuDocEditor::generate_ref_map(const GP<DjVuFile> & file,
for(GPosition pos=files_list;pos;++pos)
{
GP<DjVuFile> child_file=files_list[pos];
// First: add the current file to the list of tqparents for
// the child being processed
GURL child_url=child_file->get_url();
const GUTF8String child_id(
djvm_dir->name_to_file(child_url.fname())->get_load_name());
- GMap<GUTF8String, void *> * tqparents=0;
+ GMap<GUTF8String, void *> * parents=0;
if (ref_map.tqcontains(child_id))
- tqparents=(GMap<GUTF8String, void *> *) ref_map[child_id];
+ parents=(GMap<GUTF8String, void *> *) ref_map[child_id];
else
- ref_map[child_id]=tqparents=new GMap<GUTF8String, void *>();
- (*tqparents)[id]=0;
+ ref_map[child_id]=parents=new GMap<GUTF8String, void *>();
+ (*parents)[id]=0;
// Second: go recursively
generate_ref_map(child_file, ref_map, visit_map);
}
@@ -972,22 +972,22 @@ DjVuDocEditor::remove_file(const GUTF8String &id, bool remove_unref,
// Finally, if remove_unref is TRUE, we will go down the files
// hierarchy removing every file, which becomes unreferenced.
//
// ref_map will be used to find out list of tqparents referencing
// this file (required when removing INCL chunks)
{
- // First get rid of INCL chunks in tqparents
- GMap<GUTF8String, void *> * tqparents=(GMap<GUTF8String, void *> *) ref_map[id];
- if (tqparents)
+ // First get rid of INCL chunks in parents
+ GMap<GUTF8String, void *> * parents=(GMap<GUTF8String, void *> *) ref_map[id];
+ if (parents)
{
- for(GPosition pos=*tqparents;pos;++pos)
+ for(GPosition pos=*parents;pos;++pos)
{
- const GUTF8String tqparent_id((*tqparents).key(pos));
- const GP<DjVuFile> tqparent(get_djvu_file(tqparent_id));
+ const GUTF8String parent_id((*parents).key(pos));
+ const GP<DjVuFile> tqparent(get_djvu_file(parent_id));
if (tqparent)
tqparent->unlink_file(id);
}
- delete tqparents;
- tqparents=0;
+ delete parents;
+ parents=0;
ref_map.del(id);
}
@@ -1006,10 +1006,10 @@ DjVuDocEditor::remove_file(const GUTF8String &id, bool remove_unref,
GURL child_url=child_file->get_url();
const GUTF8String child_id(
djvm_dir->name_to_file(child_url.fname())->get_load_name());
- GMap<GUTF8String, void *> * tqparents=(GMap<GUTF8String, void *> *) ref_map[child_id];
- if (tqparents) tqparents->del(id);
+ GMap<GUTF8String, void *> * parents=(GMap<GUTF8String, void *> *) ref_map[child_id];
+ if (parents) parents->del(id);
- if (remove_unref && (!tqparents || !tqparents->size()))
+ if (remove_unref && (!parents || !parents->size()))
remove_file(child_id, remove_unref, ref_map);
}
} G_CATCH(exc) {
@@ -1041,7 +1041,7 @@ DjVuDocEditor::remove_file(const GUTF8String &id, bool remove_unref)
if (!djvm_dir->id_to_file(id))
G_THROW( ERR_MSG("DjVuDocEditor.no_file") "\t"+id);
// First generate a map of references (containing the list of tqparents
// including this particular file. This will speed things up
// significatly.
GMap<GUTF8String, void *> ref_map; // GMap<GUTF8String, GMap<GUTF8String, void *> *> in fact
@@ -1058,8 +1058,8 @@ DjVuDocEditor::remove_file(const GUTF8String &id, bool remove_unref)
GPosition pos;
while((pos=ref_map))
{
- GMap<GUTF8String, void *> * tqparents=(GMap<GUTF8String, void *> *) ref_map[pos];
- delete tqparents;
+ GMap<GUTF8String, void *> * parents=(GMap<GUTF8String, void *> *) ref_map[pos];
+ delete parents;
ref_map.del(pos);
}
}
@@ -433,15 +433,15 @@ DjVuDocEditor::strip_incl_chunks(const GP<DataPool> & pool_in)
int chunk_num, DjVuPort *source)
// Will open the 'file_name' and insert it into an existing DjVuFile
- // with ID 'tqparent_id'. Will insert the INCL chunk at position chunk_num
+ // with ID 'parent_id'. Will insert the INCL chunk at position chunk_num
// Will NOT process ANY files included into the file being inserted.
// Moreover it will strip out any INCL chunks in that file...
@@ -930,7 +930,7 @@ DjVuDocEditor::generate_ref_map(const GP<DjVuFile> & file,
GMap<GURL, void *> & visit_map)
// This private function is used to generate a list (implemented as map)
- // of files referencing the given file. To get list of all tqparents
+ // of files referencing the given file. To get list of all parents
// for file with ID 'id' iterate map obtained as
// *((GMap<GUTF8String, void *> *) ref_map[id])
@@ -944,17 +944,17 @@ DjVuDocEditor::generate_ref_map(const GP<DjVuFile> & file,
{
GP<DjVuFile> child_file=files_list[pos];
- // First: add the current file to the list of tqparents for
+ // First: add the current file to the list of parents for
// the child being processed
GURL child_url=child_file->get_url();
@@ -972,22 +972,22 @@ DjVuDocEditor::remove_file(const GUTF8String &id, bool remove_unref,
// hierarchy removing every file, which becomes unreferenced.
//
- // ref_map will be used to find out list of tqparents referencing
+ // ref_map will be used to find out list of parents referencing
// this file (required when removing INCL chunks)
{
@@ -1041,7 +1041,7 @@ DjVuDocEditor::remove_file(const GUTF8String &id, bool remove_unref)
if (!djvm_dir->id_to_file(id))
G_THROW( ERR_MSG("DjVuDocEditor.no_file") "\t"+id);
- // First generate a map of references (containing the list of tqparents
+ // First generate a map of references (containing the list of parents
// including this particular file. This will speed things up
// significatly.
diff --git a/kviewshell/plugins/djvu/libdjvu/GIFFManager.cpp b/kviewshell/plugins/djvu/libdjvu/GIFFManager.cpp
index a898d4dd..9da00dfe 100644
--- a/kviewshell/plugins/djvu/libdjvu/GIFFManager.cpp
+++ b/kviewshell/plugins/djvu/libdjvu/GIFFManager.cpp
@@ -325,24 +325,24 @@ GIFFChunk::get_chunks_number(const GUTF8String &name)
//************************************************************************
void
-GIFFManager::add_chunk(GUTF8String tqparent_name, const GP<GIFFChunk> & chunk,
+GIFFManager::add_chunk(GUTF8String parent_name, const GP<GIFFChunk> & chunk,
int pos)
// tqparent_name is the fully qualified name of the PARENT
// IT MAY BE EMPTY
// All the required chunks will be created
// pos=-1 means to append the chunk
{
- DEBUG_MSG("GIFFManager::add_chunk(): Adding chunk to name='" << tqparent_name << "'\n");
+ DEBUG_MSG("GIFFManager::add_chunk(): Adding chunk to name='" << parent_name << "'\n");
DEBUG_MAKE_INDENT(3);
if (!top_level->get_name().length())
{
- if ((!tqparent_name.length())||(tqparent_name[0]!='.'))
+ if ((!parent_name.length())||(parent_name[0]!='.'))
G_THROW( ERR_MSG("GIFFManager.no_top_name") );
- if (tqparent_name.length() < 2)
+ if (parent_name.length() < 2)
{
// 'chunk' is actually the new top-level chunk
- DEBUG_MSG("since tqparent_name=='.', making the chunk top-level\n");
+ DEBUG_MSG("since parent_name=='.', making the chunk top-level\n");
if (!chunk->is_container())
G_THROW( ERR_MSG("GIFFManager.no_top_cont") );
top_level=chunk;
@@ -350,33 +350,33 @@ GIFFManager::add_chunk(GUTF8String tqparent_name, const GP<GIFFChunk> & chunk,
}
DEBUG_MSG("Setting the name of the top-level chunk\n");
- const int next_dot=tqparent_name.search('.',1);
+ const int next_dot=parent_name.search('.',1);
if(next_dot>=0)
{
- top_level->set_name(tqparent_name.substr(1,next_dot-1));
+ top_level->set_name(parent_name.substr(1,next_dot-1));
}else
{
- top_level->set_name(tqparent_name.substr(1,(unsigned int)-1));
+ top_level->set_name(parent_name.substr(1,(unsigned int)-1));
}
}
DEBUG_MSG("top level chunk name='" << top_level->get_name() << "'\n");
- if (tqparent_name.length() && tqparent_name[0] == '.')
+ if (parent_name.length() && parent_name[0] == '.')
{
- int next_dot=tqparent_name.search('.',1);
+ int next_dot=parent_name.search('.',1);
if(next_dot<0)
{
- next_dot=tqparent_name.length();
+ next_dot=parent_name.length();
}
- GUTF8String top_name=tqparent_name.substr(1,next_dot-1);
+ GUTF8String top_name=parent_name.substr(1,next_dot-1);
if (!top_level->check_name(top_name))
G_THROW( ERR_MSG("GIFFManager.wrong_name") "\t"+top_name);
- tqparent_name=tqparent_name.substr(next_dot,(unsigned int)-1);
+ parent_name=parent_name.substr(next_dot,(unsigned int)-1);
}
GP<GIFFChunk> cur_sec=top_level;
- const char * start, * end=(const char *)tqparent_name-1;
+ const char * start, * end=(const char *)parent_name-1;
do
{
for(start=++end;*end&&(*end!='.');end++)
@@ -325,24 +325,24 @@ GIFFChunk::get_chunks_number(const GUTF8String &name)
int pos)
- // tqparent_name is the fully qualified name of the PARENT
+ // parent_name is the fully qualified name of the PARENT
// IT MAY BE EMPTY
// All the required chunks will be created
diff --git a/kviewshell/plugins/djvu/libdjvu/GIFFManager.h b/kviewshell/plugins/djvu/libdjvu/GIFFManager.h
index 96f13f8f..716f66f9 100644
--- a/kviewshell/plugins/djvu/libdjvu/GIFFManager.h
+++ b/kviewshell/plugins/djvu/libdjvu/GIFFManager.h
@@ -265,8 +265,8 @@ public:
/// Sets the name of the top level chunk to {\em name}
void set_name(const GUTF8String &name);
- /** Adds the chunk {\em chunk} to chunk with name {\em tqparent_name} at
- position {\em pos}. {\em tqparent_name} may contain dots, brackets
+ /** Adds the chunk {\em chunk} to chunk with name {\em parent_name} at
+ position {\em pos}. {\em parent_name} may contain dots, brackets
and colons. All missing chunks in the chain will be created.
{\bf Examples:}
@@ -282,7 +282,7 @@ public:
;; Same thing regardless of the top-level chunk name
m.addChunk("FORM:DJVU[1]", ch);
\end{verbatim} */
- void add_chunk(GUTF8String tqparent_name, const GP<GIFFChunk> & chunk, int pos=-1);
+ void add_chunk(GUTF8String parent_name, const GP<GIFFChunk> & chunk, int pos=-1);
/** If {\em name}={\em name1}.{\em name2} where {\em name2} doesn't
contain dots, then #addChunk()# will create plain chunk with
name {\em name2} with data {\em buffer} of size {\em length} and
diff --git a/kviewshell/plugins/djvu/libdjvu/IW44EncodeCodec.cpp b/kviewshell/plugins/djvu/libdjvu/IW44EncodeCodec.cpp
index eb429563..2a4d4035 100644
--- a/kviewshell/plugins/djvu/libdjvu/IW44EncodeCodec.cpp
+++ b/kviewshell/plugins/djvu/libdjvu/IW44EncodeCodec.cpp
@@ -161,7 +161,7 @@ public:
/** Initializes an IWBitmap with image #bm#. This constructor
performs the wavelet decomposition of image #bm# and records the
corresponding wavelet coefficient. Argument #tqmask# is an optional
- bilevel image specifying the tqmasked pixels (see \Ref{IW44Image.h}). */
+ bilevel image specifying the masked pixels (see \Ref{IW44Image.h}). */
void init(const GBitmap &bm, const GP<GBitmap> tqmask=0);
// CODER
/** Encodes one data chunk into ByteStream #bs#. Parameter #parms# controls
@@ -212,7 +212,7 @@ public:
/** Initializes an IWPixmap with color image #bm#. This constructor
performs the wavelet decomposition of image #bm# and records the
corresponding wavelet coefficient. Argument #tqmask# is an optional
- bilevel image specifying the tqmasked pixels (see \Ref{IW44Image.h}).
+ bilevel image specifying the masked pixels (see \Ref{IW44Image.h}).
Argument #crcbmode# specifies how the chrominance information should be
encoded (see \Ref{CRCBMode}). */
void init(const GPixmap &bm, const GP<GBitmap> tqmask=0, CRCBMode crcbmode=CRCBnormal);
@@ -724,7 +724,7 @@ interpolate_tqmask(short *data16, int w, int h, int rowsize,
const signed char *tqmask8, int mskrowsize)
{
int i,j;
// count tqmasked bits
short *count;
GPBuffer<short> gcount(count,w*h);
short *cp = count;
@@ -851,7 +851,7 @@ forward_tqmask(short *data16, int w, int h, int rowsize, int begin, int end,
}
// Decompose
IW44Image::Transform::Encode::forward(sdata, w, h, w, scale, scale+scale);
// Cancel tqmasked coefficients
d = sdata;
m = stqmask;
for (i=0; i<h; i+=scale+scale)
@@ -947,7 +947,7 @@ IW44Image::Map::Encode::create(const signed char *img8, int imgrowsize,
// Interpolate pixels below tqmask
DJVU_PROGRESS_RUN(transf, 1);
interpolate_tqmask(data16, iw, ih, bw, msk8, mskrowsize);
// Multiscale iterative tqmasked decomposition
DJVU_PROGRESS_RUN(transf, 3);
forward_tqmask(data16, iw, ih, bw, 1, 32, msk8, mskrowsize);
}
@@ -724,7 +724,7 @@ interpolate_tqmask(short *data16, int w, int h, int rowsize,
{
int i,j;
- // count tqmasked bits
+ // count masked bits
short *count;
GPBuffer<short> gcount(count,w*h);
@@ -851,7 +851,7 @@ forward_tqmask(short *data16, int w, int h, int rowsize, int begin, int end,
// Decompose
IW44Image::Transform::Encode::forward(sdata, w, h, w, scale, scale+scale);
- // Cancel tqmasked coefficients
+ // Cancel masked coefficients
d = sdata;
m = stqmask;
@@ -947,7 +947,7 @@ IW44Image::Map::Encode::create(const signed char *img8, int imgrowsize,
DJVU_PROGRESS_RUN(transf, 1);
interpolate_tqmask(data16, iw, ih, bw, msk8, mskrowsize);
- // Multiscale iterative tqmasked decomposition
+ // Multiscale iterative masked decomposition
DJVU_PROGRESS_RUN(transf, 3);
forward_tqmask(data16, iw, ih, bw, 1, 32, msk8, mskrowsize);